:mod:`niapy.algorithms`
============================
.. automodule:: niapy.algorithms
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`niapy.algorithms.basic`
----------------------------------
.. automodule:: niapy.algorithms.basic
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`niapy.algorithms.modified`
-----------------------------------
.. automodule:: niapy.algorithms.modified
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`niapy.algorithms.other`
-----------------------------------
.. automodule:: niapy.algorithms.other
    :members:
    :undoc-members:
    :show-inheritance: